@@ -2,8 +2,8 @@
 # Licensed under the terms of the Apache License, Version 2.0. See the LICENSE file associated with the project for terms.
 """Lightweight :term:`computation` graphs for Python."""
 
-__version__ = "5.4.0"
-__release_date__ = "29 Mar 2020, 04:20"
+__version__ = "5.7.0"
+__release_date__ = "6 Apr 2020, 15:32"
 __title__ = "graphtik"
 __summary__ = __doc__.splitlines()[0]
 __license__ = "Apache-2.0"
