@@ -10,7 +10,7 @@ from typing import Any, Callable, Mapping
 import networkx as nx
 from boltons.setutils import IndexedSet as iset
 
-from .base import UNSET, Items, Plotter, aslist, astuple, jetsam
+from .base import UNSET, Items, Plottable, aslist, astuple, jetsam
 from .config import is_debug, reset_abort
 from .modifiers import optional, sideffect
 from .network import ExecutionPlan, Network, NodePredicate, Solution, yield_ops
@@ -89,7 +89,7 @@ def _make_network(
     return net
 
 
-class NetworkOperation(Operation, Plotter):
+class NetworkOperation(Operation, Plottable):
     """
     An operation that can :term:`compute` a network-graph of operations.
 
@@ -307,7 +307,7 @@ class NetworkOperation(Operation, Plotter):
             :term:`abort run` flag is reset before the :term:`execution` starts.
 
         :param named_inputs:
-            A maping of names --> values that will be fed to the `needs` of all operations.
+            A mapping of names --> values that will be fed to the `needs` of all operations.
             Cloned, not modified.
         :param outputs:
             A string or a list of strings with all data asked to compute.
