@@ -15,7 +15,7 @@ from typing import Any, Callable, Collection, List, Mapping, Optional, Tuple, Un
 import networkx as nx
 from boltons.setutils import IndexedSet as iset
 
-from .base import UNSET, Items, Plotter, aslist, astuple, jetsam
+from .base import UNSET, Items, Plottable, aslist, astuple, jetsam
 from .config import (
     get_execution_pool,
     is_abort,
@@ -52,13 +52,15 @@ class AbortedException(Exception):
 
 class IncompleteExecutionError(Exception):
     """
-    Raised by :meth:`.scream_if_incomplete()` when `netop` operations were canceled/failed.
+    Error report when any `netop` operations were canceled/failed.
 
     The exception contains 3 arguments:
 
     1. the causal errors and conditions (1st arg),
     2. the list of collected exceptions (2nd arg), and
     3. the solution instance (3rd argument), to interrogate for more.
+
+    Returned by :meth:`.check_if_incomplete()` or raised by :meth:`.scream_if_incomplete()`.
     """
 
     def __str__(self):
@@ -126,9 +128,9 @@ def _unsatisfied_operations(dag, inputs: Collection) -> List:
     return unsatisfied
 
 
-class Solution(ChainMap, Plotter):
+class Solution(ChainMap, Plottable):
     """
-    Collects outputs from operations, preserving :term:`overwrites`.
+    A chain-map collecting :term:`solution` outputs and execution state (eg :term:`overwrites`)
 
     .. attribute:: plan
 
@@ -180,6 +182,17 @@ class Solution(ChainMap, Plotter):
         self.dag = plan.dag.copy()
         # assert next(iter(dag.edges))[0] == next(iter(plan.dag.edges))[0]:
 
+    def __copy__(self):
+        clone = type(self)(self.plan, {})
+        props = (
+            "maps executed canceled finalized elapsed_ms solid _layers"
+            " is_endurance is_reschedule is_parallel is_marshal dag"
+        ).split()
+        for p in props:
+            setattr(clone, p, getattr(self, p))
+
+        return clone
+
     def __repr__(self):
         items = ", ".join(f"{k!r}: {v!r}" for k, v in self.items())
         if is_debug():
@@ -292,8 +305,8 @@ class Solution(ChainMap, Plotter):
 
         return {k: v for k, v in dd.items() if len(v) > 1}
 
-    def scream_if_incomplete(self):
-        """Raise a :class:`IncompleteExecutionError` when `netop` operations failed/canceled. """
+    def check_if_incomplete(self) -> Optional[IncompleteExecutionError]:
+        """Return a :class:`IncompleteExecutionError` if `netop` operations failed/canceled. """
         failures = {
             op: ex for op, ex in self.executed.items() if isinstance(ex, Exception)
         }
@@ -314,7 +327,13 @@ class Solution(ChainMap, Plotter):
                 f" due to x{len(failures)} failures and x{len(partial_msgs)} partial-ops:"
                 f"{''.join(err_msgs)}{''.join(partial_msgs)}"
             )
-            raise IncompleteExecutionError(msg, self)
+            return IncompleteExecutionError(msg, self)
+
+    def scream_if_incomplete(self):
+        """Raise a :class:`IncompleteExecutionError` if `netop` operations failed/canceled. """
+        ex = self.check_if_incomplete()
+        if ex:
+            raise ex
 
     def _build_pydot(self, **kws):
         """delegate to network"""
@@ -447,7 +466,7 @@ def _do_task(task):
 
 
 class ExecutionPlan(
-    namedtuple("ExecPlan", "net needs provides dag steps asked_outs"), Plotter
+    namedtuple("ExecPlan", "net needs provides dag steps asked_outs"), Plottable
 ):
     """
     A pre-compiled list of operation steps that can :term:`execute` for the given inputs/outputs.
@@ -471,7 +490,7 @@ class ExecutionPlan(
     .. attribute:: steps
 
         The tuple of operation-nodes & *instructions* needed to evaluate
-        the given inputs & asked outputs, free memory and avoid overwritting
+        the given inputs & asked outputs, free memory and avoid overwriting
         any given intermediate inputs.
     .. attribute:: asked_outs
 
@@ -760,7 +779,7 @@ class ExecutionPlan(
     def execute(self, named_inputs, outputs=None, *, name="") -> Solution:
         """
         :param named_inputs:
-            A maping of names --> values that must contain at least
+            A mapping of names --> values that must contain at least
             the compulsory inputs that were specified when the plan was built
             (but cannot enforce that!).
             Cloned, not modified.
@@ -854,7 +873,7 @@ class ExecutionPlan(
             raise
 
 
-class Network(Plotter):
+class Network(Plottable):
     """
     A graph of operations that can :term:`compile` an execution plan.
 
@@ -902,7 +921,7 @@ class Network(Plotter):
         self.needs, self.provides = collect_requirements(self.graph)
 
         #: Speed up :meth:`compile()` call and avoid a multithreading issue(?)
-        #: that is occuring when accessing the dag in networkx.
+        #: that is occurring when accessing the dag in networkx.
         self._cached_plans = {}
 
     def __repr__(self):
@@ -1117,7 +1136,7 @@ class Network(Plotter):
         Create the list of operation-nodes & *instructions* evaluating all
 
         operations & instructions needed a) to free memory and b) avoid
-        overwritting given intermediate inputs.
+        overwriting given intermediate inputs.
 
         :param pruned_dag:
             The original dag, pruned; not broken.
