@@ -18,7 +18,7 @@ log = logging.getLogger(__name__)
 
 #: A nested dictionary controlling the rendering of graph-plots in Jupyter cells,
 #:
-#: as those returned from :meth:`.Plotter.plot()` (currently as SVGs).
+#: as those returned from :meth:`.Plottable.plot()` (currently as SVGs).
 #: Either modify it in place, or pass another one in the respective methods.
 #:
 #: The following keys are supported.
@@ -202,12 +202,15 @@ def build_pydot(
     node_props=None,
     edge_props=None,
     clusters=None,
+    splines="ortho",
     legend_url="https://graphtik.readthedocs.io/en/latest/_images/GraphtikLegend.svg",
 ) -> pydot.Dot:
     """
-    Build a *Graphviz* out of a Network graph/steps/inputs/outputs and return it.
+    Build a |pydot.Dot|_ out of a Network graph/steps/inputs/outputs and return it
 
-    See :meth:`.Plotter.plot()` for the arguments, sample code, and
+    to be fed into `Graphviz`_ to render.
+
+    See :meth:`.Plottable.plot()` for the arguments, sample code, and
     the legend of the plots.
     """
     from .op import Operation
@@ -249,7 +252,10 @@ def build_pydot(
         return quote_dot_word(a)
 
     dot = pydot.Dot(
-        graph_type="digraph", label=quote_dot_word(title), fontname="italic"
+        graph_type="digraph",
+        label=quote_dot_word(title),
+        fontname="italic",
+        splines=splines,
     )
     if name:
         dot.set_name(as_identifier(name))
@@ -335,8 +341,7 @@ def build_pydot(
             if solution and dst not in solution and dst not in steps:
                 kw["color"] = broken_color
 
-        # `splines=ortho` not working :-()
-        edge = pydot.Edge(src=src_name, dst=dst_name, splines="ortho", **kw)
+        edge = pydot.Edge(src=src_name, dst=dst_name, **kw)
 
         _apply_user_props(edge, edge_props, key=(src, dst))
 
@@ -387,10 +392,10 @@ def supported_plot_formats() -> List[str]:
 
 def render_pydot(dot: pydot.Dot, filename=None, show=False, jupyter_render: str = None):
     """
-    Plot a *Graphviz* dot in a matplotlib, in file or return it for Jupyter.
+    Render a |pydot.Dot|_ instance with `Graphviz`_ in a file and/or in a matplotlib window.
 
     :param dot:
-        the pre-built *Graphviz* :class:`pydot.Dot` instance
+        the pre-built |pydot.Dot|_ instance
     :param str filename:
         Write diagram into a file.
         Common extensions are ``.png .dot .jpg .jpeg .pdf .svg``
@@ -409,9 +414,10 @@ def render_pydot(dot: pydot.Dot, filename=None, show=False, jupyter_render: str
             netop.plot(jupyter_render={"svg_element_styles": "height: 600px; width: 100%"})
 
     :return:
-        the matplotlib image if ``show=-1``, or the `dot`.
+        the matplotlib image if ``show=-1``, or the given `dot` annotated with any
+        jupyter-rendering configurations given in `jupyter_render` parameter.
 
-    See :meth:`.Plotter.plot()` for sample code.
+    See :meth:`.Plottable.plot()` for sample code.
     """
     # Save plot
     #
@@ -454,7 +460,7 @@ def legend(
     arch_url="https://graphtik.readthedocs.io/en/latest/arch.html",
 ):
     """
-    Generate a legend for all plots (see :meth:`.Plotter.plot()` for args)
+    Generate a legend for all plots (see :meth:`.Plottable.plot()` for args)
 
     :param arch_url:
         the url to the architecture section explaining *graphtik* glossary.
